@@ -216,6 +216,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
+          is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v2')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
@@ -263,6 +264,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
           is_expected.to contain_tempest_config('service_available/congress').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
